#
# spec file for package 4pane
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           4pane
Version:        8.0
Release:        bp156.2.8
Summary:        A multi-pane detailed-list file manager
License:        GPL-3.0-only
URL:            http://www.4pane.co.uk/
Source0:        https://sourceforge.net/projects/fourpane/files/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  wxWidgets-devel >= 3.0
BuildRequires:  pkgconfig(liblzma)

%description
4Pane is a multi-pane detailed-list file manager.
It favors speed over visual effects.
In addition to standard file manager features, it offers multiple undo and redo
of most operations (including deletions), archive management including "virtual
browsing" inside archives, multiple renaming/duplication of files, a terminal
emulator and user-defined tools.

%lang_package

%prep
%autosetup -p1
sed -i -e "s|\$(datadir)/doc|%{_docdir}|g" Makefile.in
sed -i -e "s|/usr/doc/4Pane/|%{_docdir}/4Pane/|g" Configure.cpp

%build
%configure
%make_build

%install
%make_install
%find_lang 4Pane
mkdir -vp %{buildroot}/%{_datadir}/applications
cd %{buildroot}/%{_datadir}/applications
ln -s ../4Pane/rc/4Pane.desktop 4Pane.desktop
pushd %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
convert -strip -resize 48x48! 4Pane.png 4Pane.png
popd
%fdupes -s %{buildroot}/%{_datadir}

%files
%doc LICENCE
%{_bindir}/%{name}
%{_bindir}/4Pane
%dir %{_datadir}/4Pane
%dir %{_datadir}/4Pane/bitmaps
%{_datadir}/4Pane/bitmaps/*
%{_datadir}/4Pane/rc
%{_datadir}/applications/4Pane.desktop
%{_datadir}/icons/hicolor/*
%{_datadir}/metainfo/4Pane.appdata.xml
%dir %{_docdir}/4Pane
%{_docdir}/4Pane/*

%files lang -f 4Pane.lang

%changelog
* Sat Nov 19 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.0
  * Compilation fixes when built against wxWidgets 3.2
  * When trying to extract an archive, recognise the 'xpi'
    extension: it's actually a zip
  * Provide a better context menu for the Terminal Emulator and
    CommandLine
    + There are now Copy and Paste entries where appropriate.
  * Fix Terminal Emulator display glitches
  * Fix moving/pasting symlinks when Retain Relative Symlinks is
    true
- Drop 0001-Compilation-fixes-for-wxWidgets-3.1.6.patch,
  0001-Compilation-fix-for-wxWidgets-3.1.5.patch,
  0001-Fix-a-wx-assert-complaining-that-a-panel-was-being-a.patch,
  0001-Fix-a-wxAssert-when-showing-the-Command-line-termina.patch
  and
  0001-Prevent-a-wx-build-warning-about-wxPATH_NORM_ALL-bei.patch
  (merged upstream)
* Thu Aug 25 2022 Luigi Baldoni <aloisio@gmx.com>
- Added 0001-Compilation-fixes-for-wxWidgets-3.1.6.patch,
  0001-Compilation-fix-for-wxWidgets-3.1.5.patch,
  0001-Fix-a-wx-assert-complaining-that-a-panel-was-being-a.patch,
  0001-Fix-a-wxAssert-when-showing-the-Command-line-termina.patch,
  and
  0001-Prevent-a-wx-build-warning-about-wxPATH_NORM_ALL-bei.patch
  to fix build with wxWidgets 3.2
* Mon Dec  7 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.0
  * Added support for GIO mounts
    + Recent distro versions use GIO to mount some usb devices
    inside /run/user/<id>/gvfs/
    4Pane now looks there for automounted DVDs, cameras and
    smart devices e.g. android phones, and adds a toolbar
    button for each, just as would happen for a usb flash
    drive.
  * Improvements to the QuickFind dialog
  * Compilation fix for >=wxWidgets 3.1.4
- Drop 4pane-fix_for_wx3.1.4.patch (merged upstream)
* Wed Oct  7 2020 Luigi Baldoni <aloisio@gmx.com>
- Add 4pane-fix_for_wx3.1.4.patch
* Wed Oct  7 2020 Luigi Baldoni <aloisio@gmx.com>
- Fix Factory build
* Sat Mar 28 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0
  * 4Pane no longer builds with wxWidgets 2.8; it now requires
    3.0 or higher.
  * There's a faster way to reach the File OpenWith menu.
    Ctrl-Alt-doubleclick will now directly show the menu.
  * When moving or pasting files, optionally retain their
    previous modification date.
  * Support extracting/verifying 'rar' archives, if 'unrar' is
    installed, but not 'rar' creation. 'unrar' is freely
    available (though with a licence restriction) but the 'rar'
    licence is too restricted.
  * Previewing images now supports svg files too.
  * Add support for the LXQt DE by recognising its default
    editor, terminal and image viewer.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Mon Dec 25 2017 p.drouand@gmail.com
- Update to version 5.0
  + There is a simpler 'Find' dialog for everyday use.
    Just as the QuickGrep dialog is good enough for most greps, a
    simple one-page QuickFind that sets just the path, pattern and
    search-type will be sufficient for most searches.
  + When large files are being moved or pasted, their progress is now
    displayed in the statusbar.
  + It is now possible to make a particular fileview order its files
    in a decimal-aware way. This is helpful in the case of files with
    names like foo1.txt, foo2.txt, foo11.txt, foo12.txt, which normally
    sort as 1, 11, 12, 2.
  + A fileview's contextmenu now has an entry that makes it sort such
    files more intelligently. Note that this only affects files with
    names that _end_ in digits, not those with digits elsewhere in the name.
  + Building 4Pane now uses Automake.
- Split out language files into their own sub-package
* Thu Jun 29 2017 bwiedemann@suse.com
- Use convert -strip to not embed timestamps in .png files
* Wed May 31 2017 aloisio@gmx.com
- Added LICENCE file
* Fri Apr 28 2017 jengelh@inai.de
- Corrected description
* Thu Apr 27 2017 aloisio@gmx.com
- Corrected summary
* Fri Feb 17 2017 olaf@aepfle.de
- Use wxWidgets-3_0
* Sun May  8 2016 aloisio@gmx.com
- Update to version 4.0:
  * Moving or pasting files now uses threads
  * This allows 4Pane to be responsive even during pastes of
    very large files, and also makes it possible to cancel such
    pastes.
  * A better method of detecting a file's system mime-type is
    now used
  * 4Pane can now be built with clang as well as with g++
  version 3.0:
  * It's now possible to use gtk3 instead of gtk2, providing the
    gtk3 version is sufficiently recent
  * 4Pane now builds and runs on GNU Hurd, though some features
    are missing: in particular FilesystemWatcher and samba support
  * There is now an optional Preview feature: hovering over an
    image or a text file will, after a delay, show the contents in
    a 'tooltip'
  * Double-clicking on a file now uses the system's mime-type
    method to decide which application to use to open the file
    Previous versions used just 4Pane's built-in method. Now by
    default both are tried in turn, the system method first,
    but this can be changed in Options > Configuring 4Pane >
    Miscellaneous > Other
  version 2.0:
  * It's now possible to mount a remote partition over ssh, using
    sshfs.
  * 4Pane now uses 'inotify' to keep it informed of changes to
    the filesystem. This means that the display updates
    to show altered dirs and files, whether they were changed by
    4Pane itself or from elsewhere. This is enabled by default.
  * Any /etc/fstab entries for network mounts (nfs, sshfs and
    samba) are now added to their 'mount' dialogs
  * There's now a separate icon for broken symlinks.
  version 1.0:
  * For the musophobic, added the ability to use the keyboard to:
    navigate to/from the panes, terminal emulator, command-line
    and toolbar textctrl; return to the last-used control;
    navigate between dir-view and file-view, and to the opposite
    twinpane; cycle through multiple open tabs;
  * User-defined command parameters can now have modifiers, better
    to specify which panes to select from.
  * When the user does Copy on a treeitem, its filepath is now
    added to the (real) clipboard too.
    If 4Pane is built against >=wxGTK-2.9 it's also added to the
    primary selection.
  * It's now possible to set a background colour to panes,
    optionally different for dirviews and fileviews.
  * Added the ability to paste only the dirs in the clipboard,
    ignoring files. This makes it easy to replicate a directory
    tree.
  * A greater range of compressed files and archives can now be
    handled.
    Assuming the relevant system libs are installed:
    Files compressed with xz, lzma, lzop and compress can now be
    decompressed and (all but the last) compressed.
    Standard 7z archives can be extracted, and tar.7z ones created
    and extracted.
    Cpio and ar archives can be extracted, as can rpm and deb
    packages.
    It's also possible to peek inside tar archives compressed with
    xz (lzma1 or 2), in addition to gzip and bzip2.
    There are now different tree icons to discriminate between
    archives, compressed archives and compressed files.
  * It's now possible to change which part of a filename is
    displayed in the 'ext' column of a fileview.
    By default an extension is still considered to start at the
    first '.', but it's now possible to change this to the last or
    the penultimate one.
  * 4Pane now will (by default) use stock icons for such things as
    Copy and Undo. Improved some non-stock icons.
  * 4Pane now acquires more information about newly-found usb
    devices, and may not have to bother the user about them.
  * There is now a built-in su/sudo front-end for executing
    commands with admin privileges. This is the default, but it's
    still possible to configure to use kdesu/gksu/etc/ instead
- Spec cleanup
* Fri Aug 17 2012 seife+obs@b1-systems.com
- fix build on 12.1+
* Sat May 28 2011 detlef@links2linux.de
- initial build for PackMan <0.0.8>
